.. econpizza documentation master file, created by
   sphinx-quickstart on Fri Feb 11 18:28:24 2022.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. include:: ../README.rst

.. toctree::
   :maxdepth: 2

   readme
   tutorial
   boehl_hommes
   modules
   indices
